*******************
waldo
*******************

overview
=============

waldo is Dorado's tool for various search tasks. waldo has the ability to plate-solve a FITS image via astrometry.net and return the image with a WCS header mounted. waldo has the ability to find stars in a FITS image and return relevent information that can be used to plot the stars or be used in further calculations.


Reference/API
=============

.. automodapi:: dorado.waldo